@@ -10,6 +10,7 @@ import numpy as np
 
 from pyrasta.io_.files import RasterTempFile
 from pyrasta.tools import _gdal_temp_dataset, _return_raster
+from pyrasta.tools.mapping import GDAL_TO_NUMPY
 from pyrasta.tools.windows import get_block_windows, get_xy_block_windows
 from pyrasta.utils import MP_CHUNK_SIZE, split_into_chunks
 from tqdm import tqdm
@@ -57,7 +58,7 @@ def _op(raster1, out_file, raster2, op_type):
 
 def _raster_calculation(raster_class, sources, fhandle, window_size,
                         gdal_driver, data_type, no_data, nb_processes,
-                        chunksize):
+                        chunksize, description):
     """ Calculate raster expression
 
     """
@@ -65,47 +66,30 @@ def _raster_calculation(raster_class, sources, fhandle, window_size,
         window_size = (window_size, window_size)
 
     master_raster = sources[0]
-    window_gen = ([src._gdal_dataset.ReadAsArray(*w) for src in sources] for w
-                  in get_xy_block_windows(window_size, master_raster.x_size, master_raster.y_size))
-    width = int(master_raster.x_size / window_size[0]) + min(1, master_raster.x_size % window_size[0])
-    height = int(master_raster.y_size / window_size[1]) + min(1, master_raster.y_size % window_size[1])
+    window_gen = ([src._gdal_dataset.ReadAsArray(*w).astype(GDAL_TO_NUMPY[data_type])
+                   for src in sources] for w in get_xy_block_windows(window_size,
+                                                                     master_raster.x_size,
+                                                                     master_raster.y_size))
+    width = int(master_raster.x_size /
+                window_size[0]) + min(1, master_raster.x_size % window_size[0])
+    height = int(master_raster.y_size /
+                 window_size[1]) + min(1, master_raster.y_size % window_size[1])
 
     with RasterTempFile(gdal_driver.GetMetadata()['DMD_EXTENSION']) as out_file:
 
         is_first_run = True
         y = 0
-        # pgbar = tqdm(total=master_raster.y_size // window_size[1] + int(master_raster.y_size %
-        #                                                                 window_size[1] != 0),
-        #              desc="Calculate raster expression")
 
         for win_gen in tqdm(split_into_chunks(window_gen, width),
                             total=height,
-                            desc="Calculate raster expression"):
-        # while y < master_raster.y_size:
-
-            # y_size = min(window_size[1], master_raster.y_size - y)
-
-            # arrays = []
-            # for src in sources:
-            #     array = src._gdal_dataset.ReadAsArray(0, y, None, y_size).astype("float32")
-            #     array[array == src.no_data] = np.nan
-            #     arrays.append(array)
-
-            # window_gen = ([array[w[1]:w[1] + w[3], w[0]:w[0] + w[2]] for array in arrays] for w
-            #               in get_xy_block_windows(window_size, master_raster.x_size, y_size))
-            # window_gen = ([src._gdal_dataset.ReadAsArray(*w) for src in sources] for w
-            #               in get_xy_block_windows(window_size, master_raster.x_size, y_size))
+                            desc=description):
 
             with mp.Pool(processes=nb_processes) as pool:
-                result = np.concatenate(list(pool.map(fhandle,
-                                                      win_gen,
-                                                      chunksize=chunksize)),
+                result = np.concatenate(list(pool.imap(fhandle,
+                                                       win_gen,
+                                                       chunksize=chunksize)),
                                         axis=1)
 
-            # result[np.isnan(result)] = no_data
-
-            # pgbar.update(1)
-
             if is_first_run:
                 if result.ndim == 2:
                     nb_band = 1
